@@ -2277,7 +2277,7 @@ gok_spy_find_and_append_toolbar_items (Accessible *root, AccessibleNodeFlags fla
 	gboolean retval = FALSE;
 
 	if (Accessible_isAction (root)) {
-		_priv_ui_nodes = gok_spy_append_node (_priv_ui_nodes, child, flags);
+		_priv_ui_nodes = gok_spy_append_node (_priv_ui_nodes, root, flags);
 		retval = TRUE;
 		/* uncomment if we don't care about children of actionables: */
 		/* return; */
